;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; TopHAT Installer
; UAC plug-in must be installed
;  - UAC.dll in the NSIS/Plugins folder
;  - UAC.nsh in the NSIS/Include folder
; DotNET plug-in must be installed
;  - DotNet.nsh in the NSIS/Include folder
; x64 plug-in must be installed
;  - x64.nsh in the NSIS/Include folder
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;---------------------------------
;Include Libraries

  !include "MUI2.nsh"
  !include "UAC.nsh"
  !include "LogicLib.nsh"
  !include "x64.nsh"
  !include "FileFunc.nsh"
  !include "TextFunc.nsh"

;----------------------------------
; Define constants in this version

    !define SMPROGRAM_NAME 	"Texas Instruments Inc"	             /* folder to store in Start Menu and program files ()*/
    !define APP_NAME 		"TUSB3410 Driver Installer"        /* Name of the aplication	*/
    !define VERSION 		"6.7.4.0"			     /* version of the aplication	*/
    
;----------------------------------
;Compress algoritm

  SetCompressor lzma
  ShowInstDetails show
;--------------------------------------------------
;Declaration variable

var /GLOBAL CMD_ARGS
var /GLOBAL Silen
var /GLOBAL Silens

Var title
Var text
var Path
var BaseName
var TextLine
var comp

RequestExecutionLevel user
;----------------------------------
;Interface Configuration

  !define MUI_HEADERIMAGE
  !define MUI_HEADERIMAGE_BITMAP "Header Installer.bmp"
  !define MUI_HEADERIMAGE_RIGHT
  !define MUI_ABORTWARNING

;----------------------------------
;Pages
!insertmacro GetParameters
  ;Welcome page
           !define MUI_WELCOMEPAGE_TITLE_3LINES
  	!insertmacro MUI_PAGE_WELCOME

  ;License page
	!define MUI_LICENSEPAGE_RADIOBUTTONS
  	!insertmacro MUI_PAGE_LICENSE "LICENSE.rtf"

  ;Directory page
  	!insertmacro MUI_PAGE_DIRECTORY

  ;Install files page
  	!insertmacro MUI_PAGE_INSTFILES

  ;Finish page
	!define MUI_FINISHPAGE_TITLE $title
        !define MUI_FINISHPAGE_TEXT $text
  	!insertmacro MUI_PAGE_FINISH

;-------------------------------------
;Uninstall pages
        !define MUI_WELCOMEPAGE_TITLE_3LINES
	!insertmacro MUI_UNPAGE_WELCOME
	!insertmacro MUI_UNPAGE_CONFIRM
	!insertmacro MUI_UNPAGE_INSTFILES
	!insertmacro MUI_UNPAGE_FINISH

;--------------------------------------
;Languages
	!insertmacro MUI_LANGUAGE "English"

!macro Init thing

SetErrorLevel 0
uac_tryagain:
!insertmacro UAC_RunElevated
${Switch} $0
${Case} 0
	${IfThen} $1 = 1 ${|} Quit ${|} ;we are the outer process, the inner process has done its work, we are done
	${IfThen} $3 <> 0 ${|} ${Break} ${|} ;we are admin, let the show go on
	${If} $1 = 3 ;RunAs completed successfully, but with a non-admin user
		MessageBox mb_YesNo|mb_IconExclamation|mb_TopMost|mb_SetForeground "This ${thing} requires admin privileges, try again" /SD IDNO IDYES uac_tryagain IDNO 0
	${EndIf}
	;fall-through and die
${Case} 1223
	MessageBox mb_IconStop|mb_TopMost|mb_SetForeground "This ${thing} requires admin privileges, aborting!"
	Quit
${Case} 1062
	MessageBox mb_IconStop|mb_TopMost|mb_SetForeground "Logon service not running, aborting!"
	Quit
${Default}
	MessageBox mb_IconStop|mb_TopMost|mb_SetForeground "Unable to elevate to administrator level, error $0"
	Quit
${EndSwitch}

SetErrorLevel 0
SetShellVarContext all
!macroend

Var STR_HAYSTACK
Var STR_NEEDLE
Var STR_CONTAINS_VAR_1
Var STR_CONTAINS_VAR_2
Var STR_CONTAINS_VAR_3
Var STR_CONTAINS_VAR_4
Var STR_RETURN_VAR


Function StrContains
  Exch $STR_NEEDLE
  Exch 1
  Exch $STR_HAYSTACK
  ; Uncomment to debug
  ;MessageBox MB_OK 'STR_NEEDLE = $STR_NEEDLE STR_HAYSTACK = $STR_HAYSTACK '
    StrCpy $STR_RETURN_VAR ""
    StrCpy $STR_CONTAINS_VAR_1 -1
    StrLen $STR_CONTAINS_VAR_2 $STR_NEEDLE
    StrLen $STR_CONTAINS_VAR_4 $STR_HAYSTACK
    loop:
      IntOp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_1 + 1
      StrCpy $STR_CONTAINS_VAR_3 $STR_HAYSTACK $STR_CONTAINS_VAR_2 $STR_CONTAINS_VAR_1
      StrCmp $STR_CONTAINS_VAR_3 $STR_NEEDLE found
      StrCmp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_4 done
      Goto loop
    found:
      StrCpy $STR_RETURN_VAR $STR_NEEDLE
      Goto done
    done:
   Pop $STR_NEEDLE ;Prevent "invalid opcode" errors and keep the
   Exch $STR_RETURN_VAR
FunctionEnd

!macro _StrContainsConstructor OUT NEEDLE HAYSTACK
  Push "${HAYSTACK}"
  Push "${NEEDLE}"
  Call StrContains
  Pop "${OUT}"
!macroend

!define StrContains '!insertmacro "_StrContainsConstructor"'

;--------------------------------------------
;Function to version compare

Function VersionCompare
	!define VersionCompare `!insertmacro VersionCompareCall`

	!macro VersionCompareCall _VER1 _VER2 _RESULT
		Push `${_VER1}`
		Push `${_VER2}`
		Call VersionCompare
		Pop ${_RESULT}
	!macroend

	Exch $1
	Exch
	Exch $0
	Exch
	Push $2
	Push $3
	Push $4
	Push $5
	Push $6
	Push $7

	begin:
	StrCpy $2 -1
	IntOp $2 $2 + 1
	StrCpy $3 $0 1 $2
	StrCmp $3 '' +2
	StrCmp $3 '.' 0 -3
	StrCpy $4 $0 $2
	IntOp $2 $2 + 1
	StrCpy $0 $0 '' $2

	StrCpy $2 -1
	IntOp $2 $2 + 1
	StrCpy $3 $1 1 $2
	StrCmp $3 '' +2
	StrCmp $3 '.' 0 -3
	StrCpy $5 $1 $2
	IntOp $2 $2 + 1
	StrCpy $1 $1 '' $2

	StrCmp $4$5 '' equal

	StrCpy $6 -1
	IntOp $6 $6 + 1
	StrCpy $3 $4 1 $6
	StrCmp $3 '0' -2
	StrCmp $3 '' 0 +2
	StrCpy $4 0

	StrCpy $7 -1
	IntOp $7 $7 + 1
	StrCpy $3 $5 1 $7
	StrCmp $3 '0' -2
	StrCmp $3 '' 0 +2
	StrCpy $5 0

	StrCmp $4 0 0 +2
	StrCmp $5 0 begin newer2
	StrCmp $5 0 newer1
	IntCmp $6 $7 0 newer1 newer2

	StrCpy $4 '1$4'
	StrCpy $5 '1$5'
	IntCmp $4 $5 begin newer2 newer1

	equal:
	StrCpy $0 0
	goto end
	newer1:
	StrCpy $0 1
	goto end
	newer2:
	StrCpy $0 2

	end:
	Pop $7
	Pop $6
	Pop $5
	Pop $4
	Pop $3
	Pop $2
	Pop $1
	Exch $0
FunctionEnd

;;;;;;;;;;;;;;;;;;;;;;;;;
; General Configuration ;
;                       ;
;;;;;;;;;;;;;;;;;;;;;;;;;

        BrandingText "${SMPROGRAM_NAME}"

	OutFile "Setup.exe"

	Name "TUSB3410 Driver Installer"

	Caption "TUSB3410 Driver Installer ${VERSION} Setup"

;Icon "OS_Independent/${ICON}"

	CRCCheck on

	XPStyle on
	
	VIProductVersion 6.7.4.0
VIAddVersionKey ProductName "${APP_NAME}"
VIAddVersionKey Comments "TUSB3410 Driver Installer. For additional details, visit www.ti.com"
VIAddVersionKey CompanyName "Texas Instruments Incorporated"
VIAddVersionKey LegalCopyright " Copyright 1995-2012 Texas Instruments Incorporated. All rights reserved."
VIAddVersionKey FileDescription "${APP_NAME}"
VIAddVersionKey FileVersion ${Version}
VIAddVersionKey ProductVersion ${Version}
VIAddVersionKey InternalName "TUSB3410 Driver Installer v6.7.4.0"
VIAddVersionKey OriginalFilename "${APP_NAME}.exe"
;--------------------------------------------------
;define directory

InstallDir "C:\Windows\tiinst"

;--------------------------------------------------
; check if the program has already been installed, if so, take this dir
; as install dir
	InstallDirRegKey HKLM "SOFTWARE\${APP_NAME}" "Install_Dir"

;messsage for select directory dialog
	DirText "Please select your installation directory:"

;When finish keep open aplication
	AutoCloseWindow false

;show installation details
	ShowInstDetails show

;Overwrite files
	SetOverwrite on

;Optimization for complilation
	SetDatablockOptimize on

;enable installer compresion
	SetCompress auto

;message for uninstall
	UninstallText "Uninstall ${APP_NAME}"

;Attempt to give the UAC plug-in a user process and an admin process.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;
; Install settings                                                    ;
;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

Section "${APP_NAME}"
	
;installation for current user

SetShellVarContext current

SectionIn RO

${If} ${RunningX64}
 CreateDirectory "$INSTDIR\${APP_NAME}"				/* Here we add all files to unpackage  */

        CopyFiles "64-bit\*.*" "$INSTDIR\${APP_NAME}"

${Else}
 CreateDirectory "$INSTDIR\${APP_NAME}"				/* Here we add all files to unpackage  */

        CopyFiles "32-bit\*.*" "$INSTDIR\${APP_NAME}"
${EndIf}


        CopyFiles LICENSE.rtf "$INSTDIR\${APP_NAME}\LICENSE.rtf"

;installation for current user

	SetShellVarContext current

;--------------------------------------------------
;create directory  and shortcuts

;--------------------------------------------------
;create register keys

 	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"DisplayName" "${APP_NAME} ${VERSION}"

       	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"UninstallString" '"$INSTDIR\${APP_NAME}\uninstall.exe"'

	;WriteRegStr HKLM \
                ;"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
                ;"DisplayIcon" "$INSTDIR\${APP_NAME}\${ICON}"

	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"Publisher" "Texas Instruments Inc."

	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"DisplayVersion" "${VERSION}"

	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"Comments" "Texas Instruments ${APP_NAME}"

	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"URLInfoAbout" "http://www.ti.com"

	WriteRegStr HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"HelpLink" "mailto:cis_apps_support@list.ti.com"

	WriteRegDWORD HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"NoModify" 1

 	WriteRegDWORD HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	"NoRepair" "1"
            	
        WriteRegDWORD HKLM \
            	"SYSTEM\CurrentControlSet\Control\usbflags\104C82410002" \
            	"DisableLPM" "00000001"
            	
 	${GetSize} "$INSTDIR" "/S=0K" $0 $1 $2
 	IntFmt $0 "0x%08X" $0

	WriteRegDWORD HKLM \
            	"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" \
            	 "EstimatedSize" "$0"

        WriteUninstaller "$INSTDIR\${APP_NAME}\uninstall.exe"
        
       
SetOutPath "$INSTDIR\${APP_NAME}"

          ;nsExec::Exec '"usbinst.exe" -u'

          
          ;Execwait '"usbinst.exe" -u'
          nsExec::Exec '"Driver_Inst.exe" "/u" "usbuart3410.inf"'
          
${DisableX64FSRedirection}

          IfFileExists "$WINDIR\System32\drivers\umpusbvista.sys" FileExists Next
FileExists:

          ;MessageBox MB_OK "borrando $WINDIR\System32\drivers\Apploader.SYS"
          Delete "$WINDIR\System32\drivers\umpusbvista.sys"
Next:

          ;MessageBox MB_OK "va a borrar $WINDIR\System32\drivers\DockPort_Programmer.bin"
          IfFileExists "$WINDIR\System32\drivers\umpf3410.i51" FileExists1 Next1
FileExists1:

           ;MessageBox MB_OK "borrando $WINDIR\System32\drivers\DockPort_Programmer.bin"
           Delete "$WINDIR\System32\drivers\umpf3410.i51"
Next1:

	${Locate} "C:\Windows\inf" "/M=oem???.inf /L=F " "Example2"


${EnableX64FSRedirection}

          ;nsExec::Exec "usbinst.exe"
          ;Execwait "usbinst.exe"
          nsExec::Exec '"Driver_Inst.exe" "/i" "usbuart3410.inf"'

              Strcpy $title "Completing the TUSB3410 Driver Setup Wizard"
              Strcpy $text  "TUSB3410 Driver has been installed on your computer.$\n$\nClick finish to close this wizard"
              
SetOutPath "$INSTDIR\${APP_NAME}"

              ;SetRebootFlag  true


SectionEnd


Function un.RMDirUP
  !define RMDirUP '!insertmacro RMDirUPCall'
  !macro RMDirUPCall _PATH
    push '${_PATH}'
    Call un.RMDirUP
  !macroend
  ; $0 - current folder
  ClearErrors
  Exch $0
  ${GetParent} "$0" $R0
  ${GetRoot} "$0" $R1
  StrCmp $R0 $R1 Skip 0
  RMDir "$R0"
  IfErrors Skip
    ${RMDirUP} "$R0"
  Skip:
  Pop $0
FunctionEnd

;;;;;;;;;;;;;;;;;;;;;;
; Uninstall settings ;
;;;;;;;;;;;;;;;;;;;;;;

Section "Uninstall"

	Delete "$INSTDIR\uninstall.exe"

SetShellVarContext current

        Delete "$DESKTOP\${APP_NAME}.lnk"
        
SetOutPath "$INSTDIR"

          ;nsExec::Exec '"usbinst.exe" -u'
          
          ;Execwait '"usbinst.exe" -u'
          
          nsExec::Exec '"Driver_Inst.exe" "/u" "usbuart3410.inf"'
        
SetOutPath $INSTDIR
 
	Delete "$INSTDIR\*.*"

	RMDir /r  $INSTDIR

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\${APP_NAME}.lnk"

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\Uninstall.lnk"

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\*.*"

SetOutPath "$DESKTOP"

	Delete "$DESKTOP\${APP_NAME}.lnk"

SetOutPath "$SMPROGRAMS\${SMPROGRAM_NAME}"

	RMDir  /r "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}"

SetOutPath "$SMPROGRAMS"

	RMDir "$SMPROGRAMS\${SMPROGRAM_NAME}"

 Delete "$INSTDIR\*.*"

 RMDir /r "$INSTDIR"

	   ${RMDirUP} "$INSTDIR"   ;remove $INSTDIR's parents (if each is empty ONLY)

SetShellVarContext all

Delete "$INSTDIR\uninstall.exe"

 Delete "$INSTDIR\*.*"

	RMDir /r $INSTDIR

	${RMDirUP} "$INSTDIR"   ;remove $INSTDIR's parents (if each is empty ONLY)

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\${APP_NAME}.lnk"

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\Uninstall.lnk"

	Delete "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}\*.*"

SetOutPath "$DESKTOP"

	Delete "$DESKTOP\${APP_NAME}.lnk"

SetOutPath "$SMPROGRAMS\${SMPROGRAM_NAME}"

	RMDir  /r "$SMPROGRAMS\${SMPROGRAM_NAME}\${APP_NAME}"

SetOutPath "$SMPROGRAMS"

	RMDir "$SMPROGRAMS\${SMPROGRAM_NAME}"


	DeleteRegKey HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}"
	
	;DeleteRegvalue HKLM "SYSTEM\CurrentControlSet\Control\usbflags\104C82410002" "DisableLPM"
	
	${DisableX64FSRedirection}
 IfFileExists "$WINDIR\System32\drivers\umpusbvista.sys" FileExists Next
FileExists:

        ;MessageBox MB_OK "borrando $WINDIR\System32\drivers\Apploader.SYS"
        Delete "$WINDIR\System32\drivers\umpusbvista.sys"
Next:

        ;MessageBox MB_OK "va a borrar $WINDIR\System32\drivers\DockPort_Programmer.bin"
        IfFileExists "$WINDIR\System32\drivers\umpf3410.i51" FileExists1 Next1
FileExists1:

           ;MessageBox MB_OK "borrando $WINDIR\System32\drivers\DockPort_Programmer.bin"
        Delete "$WINDIR\System32\drivers\umpf3410.i51"
Next1:

	
SectionEnd

;----------------------------------
; Function to validate old installation and check version

Function .onInit

!insertmacro Init "installer"

 GetVersion::WindowsVersion
Pop $R0


${VersionCompare} $R0 "5.1" $R1

${If} $R1 == "2"
  MessageBox MB_OK|MB_ICONEXCLAMATION \
  "This software can only be installed on Windows XP or higher, please check the system requirements in the documentation."
  Abort
${EndIf}

;------------------------------------------------------------------------------------------------
;This section is for set installer silen or normal

        StrCpy $CMD_ARGS ""
        ${GetParameters} $CMD_ARGS
        ;MessageBox MB_OK $CMD_ARGS
        
        ${GetOptions} $CMD_ARGS "/Silent="  $Silen
        ;MessageBox MB_OK $Silen

        ${StrContains} $Silens "-s" $CMD_ARGS
        ;messagebox mb_ok $0
        ${If} $Silens == "-s" ;if args = -S goto silent else goto normal installation
        #Execute silent installation
        ;MessageBox MB_OK "silent"
        SetSilent silent
        ${Elseif} $Silen == "Yes" ;if args = -S goto silent else goto normal installation
        SetSilent silent
        ${Else} #Execute non-silent installation
        ;MessageBox MB_OK "normal"
        SetSilent normal
        ${EndIf}

       
;Read register key Uninstall string

  	ReadRegStr $R0 HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" "UninstallString"

  StrCmp $R0 "" done

;Read register key Display version

 	ReadRegStr $R2 HKLM "SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall\${APP_NAME}" "DisplayVersion"

;Compare version intalled vs intallation

  ${VersionCompare} $R2 "${VERSION}" $R1

;versions are equal

 StrCmp $R1 "0" "" compare1

  MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION \
  "This version of ${APP_NAME} is already installed. $\n$\nClick `OK` to uninstall the version of your computer \
   or `Cancel` to cancel this wizard" \
  IDOK uninst
  Abort

;installed version are newest

compare1:
StrCmp $R1 "1" "" compare2

  MessageBox MB_OK|MB_ICONEXCLAMATION \
  "The  Installer detects a newest version of ${APP_NAME} installed on this computer."
  Abort

;installation version are the same version of the installer version

compare2:
StrCmp $R1 "2" "" done

  MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION \
  "An old version of ${APP_NAME} is already installed. $\n$\nClick `OK` to remove the \
  previous version or `Cancel` to cancel this upgrade." \
  IDOK uninst
  Abort

; run uninstaller if a previos version are installed

;Run the uninstaller
uninst:
       ClearErrors

        ${If} $Silens == "-s" ;if args = -S goto silent else goto normal installation
        #Execute silent installation
        ;MessageBox MB_OK "silent"
        ExecWait "$R0 /Silent=Yes" ;Do not copy the uninstaller to a temp file
        ${Elseif} $Silen == "Yes"
        #Execute silent installation
        ExecWait "$R0 /Silent=Yes" ;Do not copy the uninstaller to a temp file
        ${Else} #Execute non-silent installation
        ;MessageBox MB_OK "normal"
        ExecWait '$R0' ;Do not copy the uninstaller to a temp file
        ${EndIf}
abort
  IfErrors no_remove_uninstaller done
  
  no_remove_uninstaller:

; finish function
done:

FunctionEnd

Function Example2
        ${LineRead} "$R9" "6" $TextLine
	
	${StrContains} $comp "usbuart3410" "$TextLine"
	StrCmp $comp "" here

	;MessageBox MB_OK "$TextLine"
	${GetParent} "$R9" $Path
	${GetBaseName} "$R9" $BaseName
        delete $R9
        delete $Path\$BaseName.PNF
        ;MessageBox MB_OK "$Path\$BaseName.PNF"
here:
	Push $0
FunctionEnd

Function un.StrContain
  Exch $STR_NEEDLE
  Exch 1
  Exch $STR_HAYSTACK
  ; Uncomment to debug
  ;MessageBox MB_OK 'STR_NEEDLE = $STR_NEEDLE STR_HAYSTACK = $STR_HAYSTACK '
    StrCpy $STR_RETURN_VAR ""
    StrCpy $STR_CONTAINS_VAR_1 -1
    StrLen $STR_CONTAINS_VAR_2 $STR_NEEDLE
    StrLen $STR_CONTAINS_VAR_4 $STR_HAYSTACK
    loop:
      IntOp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_1 + 1
      StrCpy $STR_CONTAINS_VAR_3 $STR_HAYSTACK $STR_CONTAINS_VAR_2 $STR_CONTAINS_VAR_1
      StrCmp $STR_CONTAINS_VAR_3 $STR_NEEDLE found
      StrCmp $STR_CONTAINS_VAR_1 $STR_CONTAINS_VAR_4 done
      Goto loop
    found:
      StrCpy $STR_RETURN_VAR $STR_NEEDLE
      Goto done
    done:
   Pop $STR_NEEDLE ;Prevent "invalid opcode" errors and keep the
   Exch $STR_RETURN_VAR
FunctionEnd

!macro _StrContainConstructor OUT NEEDLE HAYSTACK
  Push "${HAYSTACK}"
  Push "${NEEDLE}"
  Call un.StrContain
  Pop "${OUT}"
!macroend

!define StrContain '!insertmacro "_StrContainConstructor"'

Function un.onInit

!insertmacro Init "uninstaller"

    StrCpy $CMD_ARGS ""
        ${GetParameters} $CMD_ARGS
        ;MessageBox MB_OK $CMD_ARGS

        ${GetOptions} $CMD_ARGS "/Silent="  $Silen
        ;MessageBox MB_OK $Silen
        
        ${StrContain} $Silens "-s" $CMD_ARGS
        ;messagebox mb_ok $0
        ${If} $Silens == "-s" ;if args = -S goto silent else goto normal installation
        #Execute silent installation
        ;MessageBox MB_OK "silent"
        SetSilent silent
        ${Elseif} $Silen == "Yes" ;if args = -S goto silent else goto normal installation
        SetSilent silent
        ${Else} #Execute non-silent installation
        ;MessageBox MB_OK "normal"
        SetSilent normal
        ${EndIf}
        
FunctionEnd